/* -*- mode: c++; c-basic-offset: 3; -*- */
#include "Bartlett.hh"
#include "Blackman.hh"
#include "FlatTop.hh"
#include "Hamming.hh"
#include "Hanning.hh"
#include "Uniform.hh"
#include "Welch.hh"
#include <string>
#include <cstring>
#include <memory>
#include <stdexcept>

static int
ccmp(const std::string& a, const std::string& b) {
  return strcasecmp(a.c_str(), b.c_str());
}

using namespace std;
     
window_api*
window_factory(const std::string& name, size_t N) {
  if (!ccmp(name, "bartlett")) {
    return new Bartlett(N);
  }
  else if (!ccmp(name, "blackman")) {
    return new Blackman(N);
  }
  else if (!ccmp(name, "flattop")) {
    return new FlatTop(N);
  }
  else if (!ccmp(name, "hamming")) {
    return new Hamming(N);
  }
  else if (!ccmp(name, "hanning") || !ccmp(name, "hann")) {
    return new Hanning(N);
  }
  else if (!ccmp(name, "uniform") ||
	   !ccmp(name, "rectangle") ||
	   !ccmp(name, "square")) {
    return new Uniform(N);
  }
  else if (!ccmp(name, "welch")) {
    return new Welch(N);
  }
  else {
    throw runtime_error("window_factory: Unrecognized window type");
  }
}
